has_github_ssh_access

Function has_github_ssh_access 

pub fn has_github_ssh_access() -> bool
Check if SSH is likely configured for GitHub.

Uses BatchMode to avoid interactive prompts. If the host key is not already known, this returns false (user should run ssh -T git@github.com manually to verify and accept the host key).