pub struct CacheManager { /* private fields */ }Expand description
Discovery cache manager.
Implementations
Sourceimpl CacheManager
impl CacheManager
Sourcepub fn for_workspace(root: &Path) -> Result<Self>
pub fn for_workspace(root: &Path) -> Result<Self>
Create a cache manager for a specific workspace root path.
Cache is persisted at <workspace-root>/.git-same/cache.json.
Sourcepub fn load(&self) -> Result<Option<DiscoveryCache>>
pub fn load(&self) -> Result<Option<DiscoveryCache>>
Load the cache if it exists and is valid.
Sourcepub fn save(&self, cache: &DiscoveryCache) -> Result<()>
pub fn save(&self, cache: &DiscoveryCache) -> Result<()>
Save the cache to disk.