Module traits

Module traits 

Git operations trait definitions.

This module defines the trait abstractions for git operations, allowing for both real and mock implementations for testing.

Structs

CloneOptions
Options for cloning a repository.
FetchResult
Result of a fetch operation.
PullResult
Result of a pull operation.
RepoStatus
Status of a local repository.

Traits

GitOperations
Trait for git operations.