DiscoveryOptions

Struct DiscoveryOptions 

pub struct DiscoveryOptions {
    pub include_archived: bool,
    pub include_forks: bool,
    pub org_filter: Vec<String>,
    pub exclude_repos: Vec<String>,
}
Options for repository discovery.

Fields

include_archived: bool

Include archived repositories

include_forks: bool

Include forked repositories

org_filter: Vec<String>

Filter to specific organizations (empty = all)

exclude_repos: Vec<String>

Exclude specific repos by full name

Implementations

Source

impl DiscoveryOptions

pub fn new() -> Self

Creates default discovery options.

pub fn with_archived(self, include: bool) -> Self

Include archived repositories.

pub fn with_forks(self, include: bool) -> Self

Include forked repositories.

pub fn with_orgs(self, orgs: Vec<String>) -> Self

Filter to specific organizations.

pub fn with_exclusions(self, repos: Vec<String>) -> Self

Exclude specific repositories.

pub fn should_include(&self, repo: &Repo) -> bool

Check if a repo should be included based on filters.

pub fn should_include_org(&self, org: &str) -> bool

Check if an org should be included based on filters.