pub async fn handle_key(state: &mut SetupState, key: KeyEvent)Expand description
Handle a key event in the setup wizard.
Returns true if the event triggered an async operation that should be awaited.
pub async fn handle_key(state: &mut SetupState, key: KeyEvent)Handle a key event in the setup wizard.
Returns true if the event triggered an async operation that should be awaited.