Setup wizard state (the “Model” in Elm architecture).
Structs
- OrgEntry
- An organization entry in the org selector.
- Path
Browse Entry - A selectable directory entry in the inline path navigator.
- Path
Suggestion - A suggested directory path for the path selector.
- Provider
Choice - Represents one of the provider choices shown in step 2.
- Setup
State - The wizard state (model).
Enums
- Auth
Status - Authentication status during step 3.
- Setup
Outcome - The outcome of the setup wizard.
- Setup
Step - Which step of the wizard is active.
Functions
- tilde_
collapse - Collapse an absolute path’s home directory prefix into
~.