pub fn spawn_commit_fetch(
repo_path: PathBuf,
repo_name: String,
tx: UnboundedSender<AppEvent>,
)Expand description
Spawn an async task to fetch recent commits for a repo (post-sync deep dive).
pub fn spawn_commit_fetch(
repo_path: PathBuf,
repo_name: String,
tx: UnboundedSender<AppEvent>,
)Spawn an async task to fetch recent commits for a repo (post-sync deep dive).