Module event

Module event 

Event system: merges terminal input and backend notifications.

Enums

AppEvent
Events that the TUI loop processes.
BackendMessage
Messages from backend async operations.

Functions

spawn_event_loop
Spawn the terminal event reader in a blocking thread. Returns a receiver for AppEvents and a sender for backend to push messages.