spawn_event_loop

Function spawn_event_loop 

pub fn spawn_event_loop(
    tick_rate: Duration,
) -> (UnboundedReceiver<AppEvent>, UnboundedSender<AppEvent>)
Spawn the terminal event reader in a blocking thread. Returns a receiver for AppEvents and a sender for backend to push messages.