pub async fn handle_event(
app: &mut App,
event: AppEvent,
backend_tx: &UnboundedSender<AppEvent>,
)Expand description
Handle an incoming event, updating app state and optionally spawning backend work.
pub async fn handle_event(
app: &mut App,
event: AppEvent,
backend_tx: &UnboundedSender<AppEvent>,
)Handle an incoming event, updating app state and optionally spawning backend work.