pub struct OwnedRepo {
pub owner: String,
pub repo: Repo,
}Expand description
A repository with its owner information.
This type pairs a repository with the owner that it was discovered under, which may be an organization or the user’s personal account.
Fields
owner: StringOrganization name or username
repo: RepoThe repository
Implementations