Error types for the gisa application.
This module provides a hierarchy of error types:
AppError- Top-level application errorsProviderError- Errors from Git hosting providers (GitHub, GitLab, etc.)GitError- Errors from git command-line operations
Example
use git_same::errors::{AppError, Result};
fn do_something() -> Result<()> {
Err(AppError::config("missing required field"))
}Enums
- AppError
- Top-level application errors.
- GitError
- Errors that occur during git operations.
- Provider
Error - Errors that occur when interacting with a Git hosting provider’s API.
Type Aliases
- Result
- A convenience type alias for Results in this application.