Git operations trait definitions.
This module defines the trait abstractions for git operations, allowing for both real and mock implementations for testing.
Structs
- Clone
Options - Options for cloning a repository.
- Fetch
Result - Result of a fetch operation.
- Pull
Result - Result of a pull operation.
- Repo
Status - Status of a local repository.
Traits
- GitOperations
- Trait for git operations.