pub struct DiscoveryOptions {
pub include_archived: bool,
pub include_forks: bool,
pub org_filter: Vec<String>,
pub exclude_repos: Vec<String>,
}Expand description
Options for repository discovery.
Fields
include_archived: boolInclude archived repositories
include_forks: boolInclude forked repositories
org_filter: Vec<String>Filter to specific organizations (empty = all)
exclude_repos: Vec<String>Exclude specific repos by full name
Implementations
Sourceimpl DiscoveryOptions
impl DiscoveryOptions
Sourcepub fn with_archived(self, include: bool) -> Self
pub fn with_archived(self, include: bool) -> Self
Include archived repositories.
Sourcepub fn with_forks(self, include: bool) -> Self
pub fn with_forks(self, include: bool) -> Self
Include forked repositories.
Sourcepub fn with_exclusions(self, repos: Vec<String>) -> Self
pub fn with_exclusions(self, repos: Vec<String>) -> Self
Exclude specific repositories.
Sourcepub fn should_include(&self, repo: &Repo) -> bool
pub fn should_include(&self, repo: &Repo) -> bool
Check if a repo should be included based on filters.
Sourcepub fn should_include_org(&self, org: &str) -> bool
pub fn should_include_org(&self, org: &str) -> bool
Check if an org should be included based on filters.