Module state

Module state 

Setup wizard state (the “Model” in Elm architecture).

Structs

OrgEntry
An organization entry in the org selector.
PathBrowseEntry
A selectable directory entry in the inline path navigator.
PathSuggestion
A suggested directory path for the path selector.
ProviderChoice
Represents one of the provider choices shown in step 2.
SetupState
The wizard state (model).

Enums

AuthStatus
Authentication status during step 3.
SetupOutcome
The outcome of the setup wizard.
SetupStep
Which step of the wizard is active.

Functions

tilde_collapse
Collapse an absolute path’s home directory prefix into ~.